@@ -123,7 +123,8 @@ static const char *log_type_str[] = { "<Unknown>",
   "Found it|Found", "Didn't find it|Not Found", "Owner Maintenance", 
   "Write Note|Note|Other", 
   "Post Reviewer Note", "Enable Listing", "Publish Listing", "Will Attend", 
-  "Attended", "Webcam Photo taken", "Temporarily Disable Listing", 
+  "Attended", "Webcam Photo taken", 
+  "Temporarily Disable Listing|Cache Disabled!", 
   "Needs Maintenance", "Update Coordinates", "Unarchive",
   "Needs Archived", "Archive",
   ""};
@@ -154,7 +155,6 @@ static int str_search(const char *pstr[], char *str, char *type) {
   }
 
   fprintf(stderr, "ERROR parsing \"%s\": Unknown \"%s\"\n", type, str);
-  g_assert(0);
   return -1;
 }
 
