@@ -20,6 +20,10 @@
 #ifndef GPX_H
 #define GPX_H
 
+#ifndef NAN
+#define NAN (0.0/0.0)
+#endif
+
 #define WPT_SYM_UNKNOWN               -1
 #define WPT_SYM_MULTISTAGE             0
 #define WPT_SYM_PARKING                1
