@@ -29,6 +29,8 @@
 
 #include <locale.h>
 
+extern char *strcasestr (__const char *__haystack, __const char *__needle);
+
 #ifdef USE_MAEMO
 static void crumb_add(appdata_t *appdata, char *name, int level, 
 		      gpointer user_data);
@@ -47,10 +49,10 @@ enum {
 
 void errorf(const char *fmt, ...) {
   va_list args;
-  char *buf;
+  char *buf = NULL;
   size_t bufsize;
   char *newbuf;
-  size_t nextsize;
+  size_t nextsize = 0;
   int outsize;
   
   bufsize = 0;
@@ -216,8 +218,6 @@ static gboolean cachelist_expose(GtkWidget *widget, GdkEventExpose *event,
 				 gpointer user_data) {
   cachelist_expose_t *ce = (cachelist_expose_t*)user_data;
 
-  GtkTreePath *path = (GtkTreePath*)user_data; 
-
   if(event->type == GDK_EXPOSE) {
     if(ce->path && !ce->done) {
       gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(widget), 
@@ -284,17 +284,16 @@ void cachelist_redraw(appdata_t *appdata) {
 
 
 static gboolean cachelist_update(gpointer data) {
-  appdata_t *appdata = (appdata_t*)data;
 
   printf("cachelist timer fired!\n");
 
 #ifdef USE_MAEMO
+  appdata_t *appdata = (appdata_t*)data;
+
   if(appdata->cachelist_disable_screensaver)
     if (osso_display_blanking_pause(appdata->osso_context) != OSSO_OK) 
       fprintf(stderr, "error with display blank\n");
-#endif
 
-#ifdef USE_MAEMO
   if(appdata->cachelist_update)
     cachelist_redraw(appdata);
 #endif
@@ -884,8 +883,6 @@ gpx_t *search_do(appdata_t *appdata, gpx_t *gpx, char *phrase,
   memset(found, 0, sizeof(gpx_t));
   cache_t **cacheP = &(found->cache);
 
-  struct timezone tz;
-  
   if(what & SEARCH_FINDS) {
     time_t loc_now = localize_time(time(NULL));
     printf("now: %ld days since 1/1/1970, days hour is %ld\n", 
