@@ -25,12 +25,17 @@
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 
+#include <math.h>
+
 #if !defined(LIBXML_TREE_ENABLED) || !defined(LIBXML_OUTPUT_ENABLED)
 #error "libxml doesn't support required tree or output"
 #endif
 
 #include "gpxview.h"
 
+void gtk_text_buffer_set_can_paste_rich_text(GtkTextBuffer *buffer, gboolean);
+void gtk_text_buffer_set_rich_text_format(GtkTextBuffer *buffer, const gchar *);
+
 #define TAG_STATE  GTK_STATE_PRELIGHT
 
 static notes_t *notes_load(appdata_t *appdata, cache_t *cache) {
@@ -67,24 +72,24 @@ static notes_t *notes_load(appdata_t *appdata, cache_t *cache) {
   xmlNode *cur_node = NULL;
   for (cur_node = root_element; cur_node; cur_node = cur_node->next) {
     if (cur_node->type == XML_ELEMENT_NODE) {
-      if(strcasecmp(cur_node->name, "gpx") == 0) {
+      if(strcasecmp((char*)cur_node->name, "gpx") == 0) {
 	xmlNode *wpt_node = cur_node->children;
 	
 	while(wpt_node != NULL) {
 	  if(wpt_node->type == XML_ELEMENT_NODE) {
-	    if(strcasecmp(wpt_node->name, "wpt") == 0) {
+	    if(strcasecmp((char*)wpt_node->name, "wpt") == 0) {
 	      
 	      notes = malloc(sizeof(notes_t));
 	      memset(notes, 0, sizeof(notes_t));
 	      notes->pos = gpx_cache_pos(cache);
 
 	      char *str;
-	      if((str = xmlGetProp(wpt_node, "override"))) {
+	      if((str = (char*)xmlGetProp(wpt_node, BAD_CAST "override"))) {
 		notes->override = (strcasecmp(str, "yes") == 0);
 		xmlFree(str);
 	      }
 
-	      if((str = xmlGetProp(wpt_node, "found"))) {
+	      if((str = (char*)xmlGetProp(wpt_node, BAD_CAST "found"))) {
 		/* check if there's a valid number -> found time */
 		if(strtoul(str, NULL, 10) != 0) {
 		  notes->found = TRUE;
@@ -96,17 +101,17 @@ static notes_t *notes_load(appdata_t *appdata, cache_t *cache) {
 		xmlFree(str);
 	      }
 
-	      if((str = xmlGetProp(wpt_node, "logged"))) {
+	      if((str = (char*)xmlGetProp(wpt_node, BAD_CAST "logged"))) {
 		notes->logged = (strcasecmp(str, "yes") == 0);
 		xmlFree(str);
 	      }
 
-	      if((str = xmlGetProp(wpt_node, "lat"))) {
+	      if((str = (char*)xmlGetProp(wpt_node, BAD_CAST "lat"))) {
 		notes->pos.lat = g_ascii_strtod(str, NULL);
 		xmlFree(str);
 	      }
 
-	      if((str = xmlGetProp(wpt_node, "lon"))) {
+	      if((str = (char*)xmlGetProp(wpt_node, BAD_CAST "lon"))) {
 		notes->pos.lon = g_ascii_strtod(str, NULL);
 		xmlFree(str);
 	      }
@@ -115,8 +120,8 @@ static notes_t *notes_load(appdata_t *appdata, cache_t *cache) {
 	
 	      while (sub_node != NULL) {
 		if (sub_node->type == XML_ELEMENT_NODE) {
-		  if(strcasecmp(sub_node->name, "desc") == 0) 
-		    notes->text = 
+		  if(strcasecmp((char*)sub_node->name, "desc") == 0) 
+		    notes->text = (char*)
 		      xmlNodeListGetString(doc, sub_node->children, 1);
 		}
 		sub_node = sub_node->next;
@@ -510,25 +515,6 @@ static gboolean focus_in(GtkWidget *widget, GdkEventFocus *event,
   return FALSE;
 }
 
-static gboolean focus_out(GtkWidget *widget, GdkEventFocus *event,
-			  gpointer data) {
-  appdata_t *appdata = (appdata_t*)data;
-
-  printf("note focus out!\n");
-  
-  gtk_widget_set_sensitive(appdata->menu_cut, FALSE);
-  gtk_widget_set_sensitive(appdata->menu_copy, FALSE);
-  gtk_widget_set_sensitive(appdata->menu_paste, FALSE);
-
-  if(!appdata->active_buffer) {
-    printf("Huh? There was no active buffer!\n");
-  }
-
-  appdata->active_buffer = NULL;
-
-  return FALSE;
-}
-
 GtkWidget *cache_notes(cache_context_t *context) {
   appdata_t *appdata = context->appdata;
   cache_t *cache = context->cache;
@@ -548,8 +534,6 @@ GtkWidget *cache_notes(cache_context_t *context) {
   gtk_table_set_col_spacing(GTK_TABLE(table), 0, 16);
   gtk_table_set_col_spacing(GTK_TABLE(table), 2, 16);
 
-  GtkWidget *label;
-
   gtk_table_attach_defaults(GTK_TABLE(table),
 		    gtk_label_new(_("New coordinate:")), 0, 1, 0, 1);  
   context->notes.overridew = gtk_check_button_new_with_label(_("Override"));
